@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 require XSLoader;
@@ -25,8 +25,6 @@ BEGIN {
 }
 use constant \%constants;
 
-use Lingua::Identify::CLD2::GenConstants;
-
 require Exporter;
 our @ISA = qw(Exporter);
 
@@ -38,12 +36,6 @@ my @functions = qw(
   LanguageDeclaredName
   GetLanguageFromName
   LanguageCloseSet
-  IsLatnLanguage
-  IsOthrLanguage
-  ULScriptName
-  ULScriptCode
-  ULScriptDeclaredName
-  GetULScriptFromName
 );
 
 our @EXPORT_OK;
@@ -237,23 +229,6 @@ Quoting the CLD2 documentation:
 Given a language code or CLD2 language id,
 returns which set of statistically-close languages lang is in. 0 means "none".
 
-=head2 ULScriptName
-
-Given CLD2 ULScript id, returns the script name as a string.
-
-=head2 ULScriptCode
-
-Given CLD2 ULScript id, returns the code for the script as a string (equivalent
-to the language codes, see above).
-
-=head2 GetULScriptFromName
-
-Given a script name or code, returns the corresponding CLD2 ULScript id.
-
-=head2 DefaultLanguage
-
-Given an ULScript id, returns the most common Language (id) in that script.
-
 =head1 CAVEATS
 
 For both portability (CLD2 uses a bunch of ummm.. shell scripts as a build system)
@@ -273,6 +248,7 @@ L<Lingua::Identify::CLD>
 =head1 AUTHOR
 
 Steffen Mueller, E<lt>smueller@cpan.orgE<gt>
+
 Denis Bilenko
 
 =head1 COPYRIGHT AND LICENSE
