@@ -7,10 +7,12 @@
 #include <vector>
 
 
-void hashref_to_cldhint(pTHX_ SV *hashref, CLD2::CLDHints *cldhints);
-
 HV *resultchunk_to_hash(pTHX_ const CLD2::ResultChunk &rc);
 
 AV *resultchunk_vector_to_array(pTHX_ const CLD2::ResultChunkVector &rcv);
 
+AV* languages_to_array(CLD2::Language languages[3], int percent[3], double score[3]);
+
+CLD2::Language scalar_to_language(SV* lang);
+
 #endif
